use super::DockerCommand;
use anyhow::Result;

// simple commands
pub fn build() -> Result<()> {
    DockerCommand::docker_compose().args("build").spawn_wait()
}

pub fn down() -> Result<()> {
    DockerCommand::docker_compose().args("down").spawn_wait()
}

/// Start containers via `docker compose start`. Optionally pass containers to be started.
/// ```
/// start(None);
/// ```
/// is roughly the same as
/// `docker compose --env-file ./.env -f docker/local/docker-compose.yaml up start`
pub fn start(containers: Option<&str>) -> Result<()> {
    let args = format!("start {}", containers.unwrap_or(""));
    DockerCommand::docker_compose().args("start").spawn_wait()
}

pub fn stop() -> Result<()> {
    DockerCommand::docker_compose().args("stop").spawn_wait()
}

pub fn up() -> Result<()> {
    DockerCommand::docker_compose().args("up -d").spawn_wait()
}

// shortcuts
pub fn rebuild() -> Result<()> {
    stop()?;
    build()?;
    start(None)
}

pub fn restart() -> Result<()> {
    stop()?;
    start(None)
}
